#!/bin/sh

set -e

DIRNAME=`dirname "$0"`

. "$DIRNAME/functions.sh"

FUNCTIONS_SH="##functions.sh##"
if [ $# -ge 2 -a x"$1" = x--functions-sh ]; then
    test_enable=1
    FUNCTIONS_SH=". $2"
    shift 2
fi

if [ $# -lt 2 ]; then
    echo "Usage: `basename "$0"` [--functions-sh path] config maintscript" 1>&2
    exit 1
fi

case "$2" in
postinst)
    if [ -n "$test_enable" ]; then
        echo "$FUNCTIONS_SH"
        echo
    fi

    echo 'if [ -n "$CCLUB_CONFIG_FORCE" ]; then'
    echo '    gflags=force,'
    echo 'fi'
    echo
    echo 'if [ x"$1" = xconfigure ]; then'
    ;;

postrm)
    echo "CCLUB_CONFIG_STATE=\"$CCLUB_CONFIG_STATE\""
    echo "CCLUB_CONFIG_DCHASH_DIR=\"$CCLUB_CONFIG_DCHASH_DIR\""
    echo "CCLUB_CONFIG_FLAGS_DIR=\"$CCLUB_CONFIG_FLAGS_DIR\""
    echo "CCLUB_CONFIG_GENERATED_DIR=\"$CCLUB_CONFIG_GENERATED_DIR\""
    echo "CCLUB_CONFIG_UCF_DIR=\"$CCLUB_CONFIG_UCF_DIR\""
    echo
    echo 'if [ x"$1" = xpurge ]; then'
    ;;

*)
    echo "Unexpected maintainer script \"$2\", aborting" 1>&2
    exit 1
    ;;
esac

do_one_postinst()
{
    local action="$1"
    local dest="$2"
    local src=
    if [ -n "$3" ] ; then
        src="\$CCLUB_CONFIG_SHARE/$3"
    fi
    local flags="$4"

    case "$action" in
    copy)
        echo "    configure_via_copy \"$dest\" \"$src\" \"\${gflags}$flags\""
        did_one=1
        ;;
    debconf)
        echo "    configure_via_debconf \"$dest\" \"$src\" \"\${gflags}$flags\""
        did_one=1
        ;;
    nil)
        ;;
    script)
        echo "    \"$src\" \"$dest\" \"$src\" \"\${gflags}$flags\""
        did_one=1
        ;;
    \#*)
        ;;
    *)
        if [ -n "$action" -o -n "$dest" -o -n "$src" -o -n "$flags" ]; then
            echo "Unexpected configuration action \"$action\", aborting" 1>&2
            exit 1
        fi
        ;;
    esac
}

do_one_postrm()
{
    local action="$1"
    local dest="$2"
    local src="$3"
    local flags="$4"

    if is_flag_set "$flags" purge; then
        echo "    rm -f \"$dest\""
        did_one=1
    fi

    if [ x"$action" = xcopy ] || is_flag_set "$flags" ucf; then
        echo "    ucf --state-dir=\"\$CCLUB_CONFIG_UCF_DIR\" --purge \"$dest\""
        did_one=1
    fi

    if [ x"$action" = xdebconf ] || is_flag_set "$flags" debconf; then
        echo "    rm -f \"\$CCLUB_CONFIG_DCHASH_DIR/$dest\""
        did_one=1
    fi

    if is_flag_set "$flags" generated; then
        src=`basename "$src" | sed -e 's/^\(.*\)\..*$/\1/'`
        src="\$CCLUB_CONFIG_GENERATED_DIR/$src"
        echo "    rm -r -f \"$src\" \"${src}.md5sum\""
        did_one=1
    fi
}

exec < "$1"
while IFS=, read action dest src flags; do
    if [ x"$2" = xpostinst ]; then
        do_one_postinst "$action" "$dest" "$src" "$flags"
    elif [ x"$2" = xpostrm ]; then
        do_one_postrm "$action" "$dest" "$src" "$flags"
    fi
done

if [ -z "$did_one" ]; then
    echo '    :'
fi

echo 'fi'
